@@ -3,11 +3,11 @@ makefolds <- function(ina, nfolds = 10, stratified = TRUE, seed = NULL) {
   runs <- sapply(names, function(x) NULL)
   if ( !is.null(seed) )  set.seed(seed)
 
-  oop <- options( warn = -1 )
-  on.exit( options(oop) )
   if ( !stratified ) {
     rat <- length(ina) %% nfolds
-    mat <- matrix( Rfast2::Sample.int( length(ina) ), ncol = nfolds )
+    suppressWarnings({
+      mat <- matrix( Rfast2::Sample.int( length(ina) ), ncol = nfolds )
+    })
     mat[-c( 1:length(ina) )] <- NA
     for ( i in 1:c(nfolds - 1) )  runs[[ i ]] <- mat[, i]
     a <- prod(dim(mat)) - length(ina)
