@@ -23,7 +23,7 @@ maovjames <- function(x, ina, a = 0.05) {
   for (i in 1:k) {
     zi <- x[ina == i, ]
     mi[i, ] <- Rfast::colmeans( zi )
-    wi[, , i] <- ni[i] * chol2inv( chol( cov( zi ) ) )
+    wi[, , i] <- ni[i] * Rfast::spdinv( Rfast::cova( zi ) )
     me[i, ] <- mi[i, ] %*% wi[, , i]
   }
   W <- t( colSums( aperm(wi) ) )
